@@ -16,7 +16,7 @@ impl std::error::Error for FakeDBError {}
 impl sqllogictest::DB for FakeDB {
     type Error = FakeDBError;
 
-    fn run(&self, sql: &str) -> Result<String, FakeDBError> {
+    fn run(&mut self, sql: &str) -> Result<String, FakeDBError> {
         if sql == "select * from example_rowsort" {
             // Even if the order is not the same as `slt` file, sqllogictest will sort them before comparing.
             return Ok("1 10 2333\n2 20 2333\n10 100 2333".into());
